@@ -36,7 +36,7 @@ import logging
 
 
 __author__ = 'Thomas Perl <m@thp.io>'
-__version__ = '2.0.6'
+__version__ = '2.0.7'
 __url__ = 'http://thp.io/2010/minidb/'
 __license__ = 'ISC'
 
@@ -335,6 +335,12 @@ class Store(object):
             sql = 'DELETE FROM %s WHERE %s' % (table, ssql)
             return self._execute(sql, args).rowcount
 
+    def delete_all(self, class_):
+        self.delete_where(class_, literal('1'))
+
+    def count_rows(self, class_):
+        return next(self.query(class_, func.count(literal('*'))))[0]
+
     def query(self, class_, select=None, where=None, order_by=None, group_by=None, limit=None):
         with self.lock:
             table, slots = self._schema(class_)
@@ -701,7 +707,12 @@ def model_init(self, *args, **kwargs):
 
     # Call redirected constructor
     if '__minidb_init__' in self.__class__.__dict__:
-        getattr(self, '__minidb_init__')(*args)
+        # Any keyword arguments that are not the primary key ("id") or any of the slots
+        # will be passed to the __init__() function of the class, all other attributes
+        # will have already been initialized/set by the time __init__() is called.
+        kwargs = {k: v for k, v in kwargs.items()
+                  if k != Store.PRIMARY_KEY[0] and k not in self.__class__.__minidb_slots__}
+        getattr(self, '__minidb_init__')(*args, **kwargs)
 
 
 class MetaModel(type):
